@@ -54,7 +54,7 @@ def getSubjectHistory():
 
 def getWorksHistory():
 	worksHistory = {}
-	for hit in es.searchStatisticsData('works_history_simulation'):
+	for hit in es.searchStatisticsData('works_history'):
 		history = hit['_source']
 		worksHistory[history['vid']] = history
 	return worksHistory
@@ -111,7 +111,7 @@ def updateHistoryActions():
 	for works in worksList:
 		worksHistory[works.vid] = works.toSaveEsData()
 
-	return es.coverStatisticsDataReal('works_history_simulation', worksHistory)
+	return es.coverStatisticsDataReal('works_history', worksHistory)
 
 
 	'''
@@ -252,7 +252,7 @@ def writeEndTime(endTime):
 def readWorks():
 	worksDict = {}
 	worksActions = {}
-	for hit in es.scrollSearch('works_video_read', 'video', {"size":1000}):
+	for hit in es.scrollSearch('works_video_read', 'video', {"size":10000}):
 		worksInfo = hit['_source']
 		if worksInfo.has_key('vid') and worksInfo.has_key('aid') and worksInfo.has_key('publishtime') and worksInfo['publishtime'] != None:
 			vid = worksInfo['vid']
@@ -368,11 +368,11 @@ def addWorksPlayer(worksPlayers, actionId, uid, items):
 4: 推荐喜欢
 5: 推荐取消喜欢
 6: 推荐订阅
-7: 推荐取消订阅
+7: 推荐取消订阅(暂无)
 8: 推荐播放时长
 9: 推荐分享
 '''
-normalHotMap = {'2': 4, '3': 5, '4': 9, '10': 6, '11': 7}
+normalHotMap = {'2': 4, '3': 5, '4': 9, '26': 6}
 
 def addHotAction(hotActions, _id, createTime, actionId, _time, uid, items):
 	if actionId == '9' and items[4] == '3':
@@ -383,12 +383,12 @@ def addHotAction(hotActions, _id, createTime, actionId, _time, uid, items):
 		vid = items[4]
 		action = 2
 		value = 1
-	elif actionId == '1' and len(items) >= 8 and not bool(items[7]):
+	elif actionId == '1' and len(items) >= 8 and items[7] == '0':
 		vid = items[4]
 		action = 3
 		value = 1
 	elif normalHotMap.has_key(actionId) and len(items) >= 6 and items[5] == '1':
-		vid = items[4 if actionId in ['10', '11'] else 3]
+		vid = items[3]
 		action = normalHotMap[actionId]
 		value = 1
 	elif actionId == '6' and len(items) >= 8 and items[7] == '1':
