@@ -10,7 +10,7 @@ testEsclient = Elasticsearch(['119.23.69.206:9200'], timeout=60)
 devEsclient = Elasticsearch(['192.168.0.100:9200'], timeout=60)
 localEsclient = Elasticsearch(['127.0.0.1:9200'], http_auth=('elastic', 'changeme'), timeout=60)
 dataEsclient = Elasticsearch(['10.168.0.119:9200', '10.168.0.121:9200', '10.168.0.118:9200', '10.168.0.127:9200'], http_auth=('huangzhen', 'df25j0934j4y09hjoijoigef'), timeout=60)
-relEsclient = Elasticsearch(['10.32.0.223:9200', '10.33.0.11:9200', '10.167.0.246:9200', '10.0.0.53:9200'], http_auth=('huangzhen', 'huangzhen'), timeout=60)
+relEsclient = Elasticsearch(['10.32.0.223:9200', '10.33.0.11:9200', '10.167.0.246:9200'], http_auth=('huangzhen', 'huangzhen'), timeout=60)
 
 
 isTest = True
@@ -71,7 +71,7 @@ def updateRedisWorksHots(worksHots):
 def getAllUids(lastUid):
 	db = MySQLdb.connect("rm-bp10y51s402rn0kut.mysql.rds.aliyuncs.com", "mitaoroot", "lks213#%%Jfiewrj", "db_nt_user", charset='utf8')
 	uids = []
-	for item in searchDb(db, 'select uid from tb_user where uid > ' + str(lastUid) + ' order by uid asc limit 5000'):
+	for item in searchDb(db, 'select uid from tb_user where uid > ' + str(lastUid) + ' order by uid asc limit 1000'):
 		uids.append(item[0])
 	db.close()
 	return uids
@@ -81,11 +81,13 @@ def searchDbConfig():
 	
 	db = getDb()
 	config['hotVids'] = [item[0] for item in searchDb(db, 'select vid from work_whitelist')]
+	'''
 	now = str(int(time.time()))
 	for item in searchDb(db, 'select aid, weight from author_weight where start_time <= ' + now + ' and finish_time >= ' + now):
 		config['aidWeights'][item[0]] = item[1]
 	for item in searchDb(db, 'select vid, weight from work_weight where start_time <= ' + now + ' and finish_time >= ' + now):
 		config['vidWeights'][item[0]] = item[1]
+	'''
 	db.close()
 
 	return config
@@ -214,7 +216,7 @@ def searchPersonas(lastPersonasTime):
 	          "range": {
 	            "create_time": {
 	              "gt": timeToEsTime(lastPersonasTime),
-	              "lte": timeToEsTime(min(lastPersonasTime + 12 * 60 * 60, int(time.time()) - 90))
+	              "lte": timeToEsTime(int(time.time()) - 90 if isTest else min(lastPersonasTime + 12 * 60 * 60, int(time.time()) - 90))
 	            }
 	          }
 	        }
@@ -239,6 +241,7 @@ def scrollSearch(fullIndex, doc_type, body, searchAll=True, log=True, version=Fa
 		while len(result['hits']['hits']) != 0:
 			hits.extend(result['hits']['hits'])
 			scroll_id = result['_scroll_id']
+			#print(scroll_id)
 			result = esclient.scroll(scroll_id=scroll_id, scroll='1m')
 	else:
 		hits.extend(esclient.search(index=fullIndex, doc_type=doc_type, body=body, version=version, preference='_primary_first')['hits']['hits'])
