@@ -66,16 +66,7 @@ Trust = {
 	"timeCount": 75
 }
 
-def calSubjectScore(subjectList):
-	subjectArgs = []
-	for subject in subjectList:
-		subjectArgs.append([subject.count, subject.play, subject.replay])
-	subjectMat = imatrix.inOne(mat(subjectArgs))
-
-	for index, subject in enumerate(subjectList):
-		subject.score = (subjectMat[index, 0] * SubjectWeight['count'] + subjectMat[index, 1] * SubjectWeight['play'] + subjectMat[index, 2] * SubjectWeight['replay']) * subject.conv
-
-def calWorksScore(worksList, dauFactor=10):
+def calWorksScore(worksList):
 	if len(worksList) == 0:
 		return
 
@@ -103,42 +94,17 @@ def updateWeight(weight):
 	global Weight
 	Weight = weight
 
-def calHotV2(subjectHistory, worksHistory, worksList, dauFactor, aidWeights, vidWeights):
-	calWorksScore(worksList, 11 - dauFactor)
-
-	'''
-	baseHot = []
-	for works in worksList:
-		vid = works.vid
-		aid = works.aid
-		score = subjectHistory[aid]['score'] if subjectHistory.has_key(aid) else 0
-		ratio = worksHistory[vid]['ratio'] if worksHistory.has_key(vid) else works.ratio
-		baseHot.append([score * ratio])
-
-	baseHotMat = imatrix.inOneDiv(mat(baseHot))
-	'''
+def calHotV2(worksList):
+	calWorksScore(worksList)
 
 	hotList = {}
 	for index, works in enumerate(worksList):
 		vid = works.vid
-		#aid = works.aid
-		#actionHot = works.score * 0.9 + (worksHistory[vid]['score'] if worksHistory.has_key(vid) else 0) * 0.1
-		#actionHot = works.score
-		'''
-		totalHot = (baseHotMat[index, 0] * SubjectTotalWeight + actionHot) * 100000
-		if vidWeights.has_key(vid):
-			weight = float(vidWeights[vid])
-		elif aidWeights.has_key(int(aid)):
-			weight = float(aidWeights[int(aid)])
-		else:
-			weight = 1
-		'''
 		hotData = works.toSaveEsData()
-		#hotData['baseHot'] = baseHotMat[index, 0]
-		#hotData['totalHot'] = totalHot
-		#hotData['hot'] = totalHot * getDecayRatio(works.publishTime) * weight
 		hotData['hot'] = works.score
-		hotData['isNew'] = works.publishTime < 72 and works.resShow < 200
+		hotData['exposure'] = works.resShow
+		hotData['converRatio'] = 0 if works.resShow <= 0 else works.resShowPlay * 1.0 / works.resShow
+		hotData['completeRatio'] = 0 if works.timeCount <= 0 or works.duration <= 0 else works.timeTotal * 1.0 / works.timeCount / works.duration
 		hotList[vid] = hotData
 
 	hotListFinal = {}
