@@ -6,13 +6,15 @@ from .. import es, dataDispose, imatrix
 from numpy import *
 
 def test():
+	'''
 	ab = mat([[1, 2, 3, 4], [0.3, 3, 4, 0.1], [3, 1, 3, 5], [10, 3, 100, 30], [9, 30, 40, 99], [99, 65, 0, 39]])
 	print(ab)
 	print('----------')
 	print(imatrix.inOneDiv(ab))
 	print('----------')
 	print(imatrix.inOneDivOffStray(ab))
-	#recordEsToRedis()
+	'''
+	recordEsToRedisBatch()
 	#hotGrow()
 	'''
 	l = [[1]]
@@ -23,6 +25,38 @@ def test():
 	print(imatrix.inOne(mat(l)))
 	'''
 
+def recordEsToRedisBatch():
+	currentUid = readEndUid()
+	index = 0
+	while True:
+		start = time.time()
+		nextUids = es.getAllUids(currentUid)
+		print(time.time() - start)
+		if len(nextUids) == 0:
+			break
+		hitIntsDict = {}
+		hits = es.scrollSearch('statistics_works_hot_fixed_backups', 'recommendviewrecordsearch', {"query":{"bool":{"must":[{"range":{"time":{"lte":1550567166000}}},{"range":{"uid":{"gte":nextUids[0],"lte":nextUids[-1]}}}]}},"size":10000})
+		print(time.time() - start)
+		for hit in hits:
+			uid = hit['_source']['uid']
+			vid = str(es.getIntByVid(hit['_parent']))
+			if hitIntsDict.has_key(uid):
+				hitIntsDict[uid].append(vid)
+			else:
+				hitIntsDict[uid] = [vid]
+		for nextUid in nextUids:
+			index += 1
+			if not hitIntsDict.has_key(nextUid):
+				continue
+			hitInts = hitIntsDict[nextUid]
+			print(index, nextUid, len(hitInts))
+			es.writeIntsByUid(nextUid, hitInts)
+			writeEndUid(nextUid)
+			writeUids(nextUid)
+			currentUid = nextUid
+		print(time.time() - start)
+		gc.collect()
+
 def recordEsToRedis():
 	currentUid = readEndUid()
 	index = 0
@@ -32,17 +66,24 @@ def recordEsToRedis():
 			break
 		for nextUid in nextUids:
 			hitInts = []
-			existInts = es.getIntsByUid(nextUid)
-			hits = es.scrollSearch('statistics_works_hot_fixed_backups', 'recommendviewrecordsearch', {"query":{"bool":{"must":[{"range":{"time":{"lte":1548644400000}}},{"term":{"uid":{"value":nextUid}}}]}},"size":10000})
+			#existInts = es.getIntsByUid(nextUid)
+			#time1 = time.time()
+			hits = es.scrollSearch('statistics_works_hot_fixed_backups', 'recommendviewrecordsearch', {"query":{"bool":{"must":[{"range":{"time":{"lte":1550567166000}}},{"term":{"uid":{"value":nextUid}}}]}},"size":10000})
+			#time2 = time.time()
 			for hit in hits:
-				i = es.getIntByVid(hit['_parent'])
-				if i != None and i not in existInts:
-					hitInts.append(str(i))
+				#i = es.getIntByVid(hit['_parent'])
+				#if i != None and i not in existInts:
+				hitInts.append(str(es.getIntByVid(hit['_parent'])))
+			#time3 = time.time()
 			index += 1
 			print(index, nextUid, len(hitInts))
+			#time4 = time.time()
 			es.writeIntsByUid(nextUid, hitInts)
+			#time5 = time.time()
 			writeEndUid(nextUid)
-			writeUids(nextUid)
+			#time6 = time.time()
+			#print(time2 - time1, time3 - time2, time4 - time3, time5 - time4, time6 - time5)
+			#writeUids(nextUid)
 			currentUid = nextUid
 		gc.collect()
 	
